package login

import (
	"zombiezen.com/go/sqlite"
	"zombiezen.com/go/sqlite/sqlitex"
)

// Represents a login world server.
type LoginWorldServer struct {
	ID                    int32   `db:"id"`
	Name                  string  `db:"name"`
	Disabled              bool    `db:"disabled"`
	Account               string  `db:"account"`
	ChatShortname         string  `db:"chat_shortname"`
	Description           string  `db:"description"`
	ServerType            string  `db:"server_type"`
	Password              string  `db:"password"`
	Serverop              string  `db:"serverop"`
	LastSeen              int32   `db:"lastseen"`
	AdminID               int32   `db:"admin_id"`
	Greenname             bool    `db:"greenname"`
	Showdown              int8    `db:"showdown"`
	Chat                  string  `db:"chat"`
	Note                  string  `db:"note"`
	IPAddress             string  `db:"ip_address"`
	ResetNeeded           bool    `db:"reset_needed"`
	CreatedDate           int32   `db:"created_date"`
	HideStatus            bool    `db:"hide_status"`
	HideDetails           bool    `db:"hide_details"`
	HideAdmin             bool    `db:"hide_admin"`
	HideServerlist        bool    `db:"hide_serverlist"`
	ServerURL             *string `db:"server_url"`
	ServerCategory        string  `db:"server_category"`
	ServerAdmin           string  `db:"server_admin"`
	ServerSticky          bool    `db:"server_sticky"`
	GMList                *string `db:"gm_list"`
	ResetZoneDescriptions bool    `db:"reset_zone_descriptions"`
	ResetLoginAppearances bool    `db:"reset_login_appearances"`
	LoginVersion          string  `db:"login_version"`
}

// Creates the login_worldservers table if it does not exist.
func CreateLoginWorldServersTable(conn *sqlite.Conn) error {
	return sqlitex.ExecScript(conn, `
		CREATE TABLE IF NOT EXISTS login_worldservers (
			id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
			name TEXT NOT NULL UNIQUE DEFAULT '',
			disabled INTEGER NOT NULL DEFAULT 0,
			account TEXT NOT NULL UNIQUE DEFAULT '',
			chat_shortname TEXT NOT NULL DEFAULT '',
			description TEXT NOT NULL,
			server_type TEXT NOT NULL DEFAULT '0',
			password TEXT NOT NULL DEFAULT '',
			serverop TEXT NOT NULL DEFAULT '',
			lastseen INTEGER NOT NULL DEFAULT 0,
			admin_id INTEGER NOT NULL DEFAULT 0,
			greenname INTEGER NOT NULL DEFAULT 0,
			showdown INTEGER NOT NULL DEFAULT 0,
			chat TEXT NOT NULL DEFAULT '0',
			note TEXT NOT NULL,
			ip_address TEXT NOT NULL DEFAULT '0',
			reset_needed INTEGER NOT NULL DEFAULT 0,
			created_date INTEGER NOT NULL DEFAULT 0,
			hide_status INTEGER NOT NULL DEFAULT 0,
			hide_details INTEGER NOT NULL DEFAULT 0,
			hide_admin INTEGER NOT NULL DEFAULT 0,
			hide_serverlist INTEGER NOT NULL DEFAULT 0,
			server_url TEXT DEFAULT '',
			server_category TEXT DEFAULT 'Standard',
			server_admin TEXT NOT NULL DEFAULT '',
			server_sticky INTEGER NOT NULL DEFAULT 0,
			gm_list TEXT DEFAULT NULL,
			reset_zone_descriptions INTEGER NOT NULL DEFAULT 0,
			reset_login_appearances INTEGER NOT NULL DEFAULT 0,
			login_version TEXT NOT NULL DEFAULT '0'
		);
	`)
}
