package login

import (
	"time"

	"zombiezen.com/go/sqlite"
	"zombiezen.com/go/sqlite/sqlitex"
)

// Represents stats for a world server.
type LoginWorldStats struct {
	ID             int32     `db:"id"`
	WorldID        int32     `db:"world_id"`
	WorldStatus    int32     `db:"world_status"`
	CurrentPlayers int32     `db:"current_players"`
	CurrentZones   int32     `db:"current_zones"`
	ConnectedTime  time.Time `db:"connected_time"`
	LastUpdate     time.Time `db:"last_update"`
	WorldMaxLevel  int8      `db:"world_max_level"`
}

// Creates a new login_worldstats table in the database.
func CreateLoginWorldStatsTable(conn *sqlite.Conn) error {
	return sqlitex.ExecScript(conn, `
		CREATE TABLE IF NOT EXISTS login_worldstats (
			id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
			world_id INTEGER NOT NULL UNIQUE DEFAULT 0,
			world_status INTEGER NOT NULL DEFAULT -1,
			current_players INTEGER NOT NULL DEFAULT 0,
			current_zones INTEGER NOT NULL DEFAULT 0,
			connected_time TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP,
			last_update TEXT NOT NULL DEFAULT '0000-00-00 00:00:00',
			world_max_level INTEGER NOT NULL DEFAULT 0
		);
	`)
}
